import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { html } from "lit-html";
import CATEGORIES from "../categories";

<Meta title={CATEGORIES.STATIC + "Text"} />

# Text

A growing collection of how to display text

## Title Text

A text that looks like a headline, but is just regular text. Classname: `ui-text-title`

<Canvas
    mdxSource={`
        <div class="ui-text-title">Title text</div>
        <div class="ui-text-title ui-text-title--light">Light title text</div>
        <div class="ui-text-title ui-text-title--bold">Bold title text</div>
        <div class="ui-text-title ui-text-title--big">Big title text</div>
        <div class="ui-text-title ui-text-title--big ui-text-title--light">Big light title text</div>
        <div class="ui-text-title ui-text-title--big ui-text-title--bold">Big bold title text</div>
    `}
>
    <Story name="Title Text">
        {html`
            <div class="ui-text-title">Title text</div>
            <div class="ui-text-title ui-text-title--light">
                Light title text
            </div>
            <div class="ui-text-title ui-text-title--bold">
                Bold title text
            </div>
            <div class="ui-text-title ui-text-title--big">Big title text</div>
            <div class="ui-text-title ui-text-title--big ui-text-title--light">
                Big light title text
            </div>
            <div class="ui-text-title ui-text-title--big ui-text-title--bold">
                Big bold title text
            </div>
        `}
    </Story>
</Canvas>

## Normal Text

The normal text can be used with `span` or `div`. Classname: `ui-text-normal`

<Canvas>
    <Story name="Normal Text">
        {html`
            <span class="ui-text-normal">Normal text</span>
            <div class="ui-text-normal ui-text-normal--bold">
                Bold normal text
            </div>
        `}
    </Story>
</Canvas>

## Tiny Text

A tiny text for statuses or labels. Classname: `ui-text-tiny`

<Canvas>
    <Story name="Tiny Text">
        {html`
            <span class="ui-text-tiny">Tiny text</span>
            <div class="ui-text-tiny ui-text-tiny--bold">
                Bold and tiny text
            </div>
        `}
    </Story>
</Canvas>

## Text Link

A typical Text Link with an optional icon. Classname: `ui-text-link`

<Canvas>
    <Story name="Text Link">
        {html`
            <a href="#" class="ui-text-link">Link</a><br />
            <a href="#" class="ui-text-link"
                >Link <ui-icon name="arrow-small-right" /></a
            ><br />
            <a href="#" class="ui-text-link ui-text-link--green">green Link</a
            ><br />
            <a href="#" class="ui-text-link ui-text-link--green"
                >green Link <ui-icon name="arrow-small-right"
            /></a>
        `}
    </Story>
</Canvas>

## Text Utility Classes

Utility Classes provide a simple single style and always start with `ui-u-`

<Canvas>
    <Story name="Text Utility Classes">
        {html`
            <div class="ui-u-text-align--center">ui-u-text-align--center</div>
            <div class="ui-u-text-align--left">ui-u-text-align--left</div>
            <div class="ui-u-text-align--right">ui-u-text-align--right</div>
            <div class="ui-u-text-uppercase">ui-u-text-uppercase</div>
            <div class="ui-u-text-bold">ui-u-text-bold</div>
        `}
    </Story>
</Canvas>

# Headlines

Different variants of headlines, that start with `ui-text-headline` and can be enhanced by adding the size name.

<Canvas>
    <Story name="Headlines">
        {html`
            <div class="ui-text-headline ui-text-headline--vast">
                Headline variant: vast
            </div>
            <div class="ui-text-headline ui-text-headline--giant">
                Headline variant: giant
            </div>
            <div class="ui-text-headline ui-text-headline--big">
                Headline variant: big
            </div>
            <div class="ui-text-headline ui-text-headline--big ui-u-text-bold">
                Headline variant: big, .ui-u-text-bold
            </div>
            <div class="ui-text-headline ui-text-headline--medium">
                Headline variant: medium
            </div>
            <div class="ui-text-headline ui-text-headline--small">
                Headline variant: small
            </div>
        `}
    </Story>
</Canvas>

## Use of H1-H6

Headline styles can also be applied to semantic headline elements. These headlines also come with preset margin values.

<Canvas>
    <Story name="Headlines H1-H6">
        {html`
            <h1 class="ui-text-headline ui-text-headline--vast">
                Headline variant: vast
            </h1>
            <h1 class="ui-text-headline ui-text-headline--giant">
                Headline variant: giant
            </h1>
            <h2 class="ui-text-headline ui-text-headline--big">
                Headline variant: big
            </h2>
            <h2 class="ui-text-headline ui-text-headline--big ui-u-text-bold">
                Headline variant: big, .ui-u-text-bold
            </h2>
            <h3 class="ui-text-headline ui-text-headline--medium">
                Headline variant: medium
            </h3>
            <h3 class="ui-text-headline ui-text-headline--small">
                Headline variant: small
            </h3>
        `}
    </Story>
</Canvas>
